<section id="testimonials" class="py-24 bg-gray-50">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-20" data-aos="fade-up">
      <span class="inline-block text-xs uppercase tracking-widest text-gray-500 mb-3">
        {{ sections.testimonials.title }}
      </span>
      <h2 class="text-3xl sm:text-4xl font-light text-gray-900 mb-4">
        {{ sections.testimonials.subtitle }}
      </h2>
      <div class="w-16 h-px bg-gray-300 mx-auto mb-6"></div>
    </div>
    
    {% if sections.testimonials.featured %}
    <div class="max-w-4xl mx-auto text-center mb-20" data-aos="fade-up">
      <blockquote class="text-2xl font-light text-gray-900 mb-8 leading-relaxed">
        "{{ sections.testimonials.featured.quote }}"
      </blockquote>
      <div class="w-16 h-px bg-gray-300 mx-auto mb-6"></div>
      <div class="font-light text-gray-600">
        {{ sections.testimonials.featured.name }}, {{ sections.testimonials.featured.title }}
      </div>
    </div>
    {% endif %}
    
    <div class="grid md:grid-cols-2 lg:grid-cols-3 gap-8">
      {% for testimonial in sections.testimonials.items %}
      <div class="bg-white p-8 border border-gray-100 hover:shadow-sm transition-shadow duration-300" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <blockquote class="text-gray-700 mb-6 font-light leading-relaxed">
          "{{ testimonial.quote }}"
        </blockquote>
        <div class="w-8 h-px bg-gray-300 mb-4"></div>
        <div class="font-light text-gray-900">{{ testimonial.name }}</div>
        <div class="text-sm text-gray-500 font-light">{{ testimonial.title }}</div>
      </div>
      {% endfor %}
    </div>
  </div>
</section>