<section id="stats" class="py-24 bg-gray-900 text-white">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-20" data-aos="fade-up">
      <span class="inline-block text-xs uppercase tracking-widest text-white/60 mb-3">
        {{ sections.stats.title }}
      </span>
      <h2 class="text-3xl sm:text-4xl font-light text-white mb-4">
        {{ sections.stats.subtitle }}
      </h2>
      <div class="w-16 h-px bg-white/30 mx-auto mb-6"></div>
    </div>
    
    <div class="grid grid-cols-2 md:grid-cols-4 gap-8">
      {% for stat in sections.stats.items %}
      <div class="text-center p-8 border border-white/10 hover:bg-white/5 transition-colors duration-300" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <div class="text-4xl font-light text-white mb-4">{{ stat.value }}</div>
        <div class="w-8 h-px bg-white/30 mx-auto mb-3"></div>
        <div class="text-sm text-white/80 font-light uppercase tracking-wide">{{ stat.label }}</div>
        {% if stat.description %}
        <p class="text-xs text-white/60 mt-2 font-light">{{ stat.description }}</p>
        {% endif %}
      </div>
      {% endfor %}
    </div>
  </div>
</section>