<section class="py-24 bg-white" id="gallery">
  <div class="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-16">
      <h2 class="text-3xl sm:text-4xl font-cinzel font-bold text-gray-900 mb-4">{{ sections.gallery.title }}</h2>
      <p class="text-base sm:text-lg text-gray-600 max-w-2xl mx-auto font-cinzel">{{ sections.gallery.subtitle }}</p>
    </div>
    <div class="grid grid-cols-1 md:grid-cols-3 gap-8">
      {% for item in sections.gallery.items %}  
      <div class="group">
        <div class="relative aspect-[1/1] overflow-hidden rounded-lg mb-4">
          <img src="{{ item.src }}" class="w-full h-full object-cover transition duration-700 group-hover:scale-105" alt="{{ item.alt }}" loading="lazy">
          <div class="absolute inset-0 bg-black/20 transition group-hover:bg-black/40"></div>
        </div>
        <h3 class="text-xl sm:text-2xl font-cinzel font-bold text-gray-900 mb-2">{{ item.caption }}</h3>
        <p class="text-gray-600 mb-4 font-cinzel">{{ item.alt }}</p>
        <a href="#view-more" class="inline-flex items-center text-primary font-medium hover:text-primary/80" aria-label="View More">View More <i class="ri-arrow-right-line ml-2"></i></a>
      </div>{% endfor %}
      
      
    </div>
  </div>
</section>