<section id="challenges" class="h-screen w-full bg-gray-50 flex items-center">
  <div class="max-w-4xl mx-auto px-4">
    <h2 class="text-4xl font-light text-gray-900 text-center mb-16" data-aos="fade-up">
      {{ sections.challenges.title }}
    </h2>
    
    <div class="grid grid-cols-2 md:grid-cols-4 gap-8">
      {% for item in sections.challenges.items %}
      <div class="text-center" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <div class="text-4xl font-light text-gray-900 mb-2">{{ item.value }}</div>
        <div class="text-sm text-gray-600">{{ item.label }}</div>
      </div>
      {% endfor %}
    </div>
  </div>
</section>
