<section id="service_features" class="py-32 bg-white">
  <div class="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-20" data-aos="fade-up">
      <h2 class="text-5xl font-bold text-gray-900 mb-6">
        {{ sections.service_features.title }}
      </h2>
    </div>
    
    <div class="grid md:grid-cols-3 gap-12">
      {% for item in sections.service_features.items %}
      <div class="group text-center" data-aos="zoom-in" data-aos-delay="{{ loop.index0 * 100 }}">
        <div class="bg-gradient-to-br from-gray-50 to-white p-12 rounded-3xl shadow-sm hover:shadow-xl transition-all duration-500 border border-gray-100 h-full">
          <div class="relative mb-8">
            <div class="absolute -inset-4 bg-gradient-to-r from-primary/20 to-secondary/20 blur-2xl opacity-0 group-hover:opacity-50 transition-opacity duration-500"></div>
            <div class="relative w-20 h-20 bg-gradient-to-br from-primary to-secondary rounded-3xl flex items-center justify-center mx-auto shadow-xl group-hover:scale-110 group-hover:rotate-6 transition-all duration-500">
              <i class="{{ item.icon | default('ri-service-line') }} text-white text-3xl"></i>
            </div>
          </div>
          
          <h3 class="text-2xl font-bold text-gray-900 mb-6 group-hover:text-primary transition-colors duration-300">
            {{ item.title }}
          </h3>
          <p class="text-gray-600 leading-relaxed text-lg">{{ item.description }}</p>
        </div>
      </div>
      {% endfor %}
    </div>
  </div>
</section>