<section id="hero" class="py-16 bg-white">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="grid lg:grid-cols-2 gap-12 items-center">
      <div class="space-y-6">
        {% if sections.hero.badge %}
        <span
          class="inline-block px-3 py-1 text-sm font-medium text-primary rounded-md"
        >
          {{ sections.hero.badge }}
        </span>
        {% endif %}

        <h1 class="text-4xl md:text-5xl font-bold text-gray-900 leading-tight">
          {{ sections.hero.title }}
        </h1>

        {% if sections.hero.subtitles %}
        <div class="flex flex-wrap gap-2">
          {% for subtitle in sections.hero.subtitles %}
          <span class="px-2 py-1 text-sm bg-gray-100 text-gray-700 rounded"
            >{{ subtitle }}</span
          >
          {% endfor %}
        </div>
        {% endif %}

        <p class="text-lg text-gray-600 leading-relaxed">
          {{ sections.hero.description }}
        </p>

        {% if sections.hero.ctaButtons %}
        <div class="flex flex-col sm:flex-row gap-4">
          {% for btn in sections.hero.ctaButtons %}
          <a
            href="{{ btn.url }}"
            class="{% if btn.style == 'filled' %}bg-primary text-white hover:bg-primary/90{% else %}bg-white text-primary border border-primary hover:bg-primary/5{% endif %} px-6 py-3 rounded-lg font-medium transition-colors text-center"
            {%
            if
            btn.ariaLabel
            %}aria-label="{{ btn.ariaLabel }}"
            {%
            endif
            %}
          >
            {{ btn.label }}
          </a>
          {% endfor %}
        </div>
        {% endif %} {% if sections.hero.stats %}
        <div class="grid grid-cols-3 gap-6 pt-6">
          {% for stat in sections.hero.stats %}
          <div class="text-center">
            <div class="text-2xl font-bold text-primary">{{ stat.value }}</div>
            <div class="text-sm text-gray-600">{{ stat.label }}</div>
          </div>
          {% endfor %}
        </div>
        {% endif %}
      </div>

      <div class="relative" data-aos="fade-left">
        {% if sections.hero.heroImage %}
        <div class="relative">
          <img
            src="{{ sections.hero.heroImage.src }}"
            alt="{{ sections.hero.heroImage.alt }}"
            class="w-full h-auto rounded-2xl shadow-lg"
            loading="{% if sections.hero.heroImage.lazyLoad %}lazy{% else %}eager{% endif %}"
          />
          <div
            class="absolute -bottom-4 -right-4 w-24 h-24 bg-primary/20 rounded-2xl -z-10"
          ></div>
        </div>
        {% endif %}
      </div>
    </div>
  </div>
</section>
