<section id="challenges" class="py-32 bg-slate-900 text-white relative overflow-hidden">
  <div class="absolute inset-0 bg-[url('data:image/svg+xml,%3Csvg width="40" height="40" viewBox="0 0 40 40" xmlns="http://www.w3.org/2000/svg"%3E%3Cg fill="none" fill-rule="evenodd"%3E%3Cg fill="%23ffffff" fill-opacity="0.05"%3E%3Cpath d="M20 20c0-5.5-4.5-10-10-10s-10 4.5-10 10 4.5 10 10 10 10-4.5 10-10zm10 0c0-5.5-4.5-10-10-10s-10 4.5-10 10 4.5 10 10 10 10-4.5 10-10z"/%3E%3C/g%3E%3C/g%3E%3C/svg%3E')] opacity-30"></div>
  
  <div class="relative max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-20" data-aos="fade-up">
      <h2 class="text-5xl font-bold text-white mb-6">
        {{ sections.challenges.title }}
      </h2>
      <p class="text-xl text-white/70 max-w-3xl mx-auto">
        {{ sections.challenges.subtitle }}
      </p>
    </div>
    
    <div class="grid md:grid-cols-2 lg:grid-cols-4 gap-8">
      {% for item in sections.challenges.items %}
      <div class="group text-center" data-aos="zoom-in" data-aos-delay="{{ loop.index0 * 100 }}">
        <div class="bg-white/5 backdrop-blur-sm p-8 rounded-2xl border border-white/10 hover:bg-white/10 transition-all duration-300 hover:scale-105">
          <div class="w-16 h-16 bg-gradient-to-br from-primary to-secondary rounded-2xl flex items-center justify-center mx-auto mb-6 shadow-lg group-hover:rotate-6 transition-transform duration-300">
            <i class="{{ item.icon | default('ri-bar-chart-line') }} text-white text-2xl"></i>
          </div>
          
          <div class="text-4xl font-bold text-white mb-3 group-hover:scale-110 transition-transform duration-300">
            {{ item.value }}
          </div>
          <div class="text-sm font-semibold text-white/80 mb-2">{{ item.label }}</div>
          
          {% if item.description %}
          <p class="text-xs text-white/60">{{ item.description }}</p>
          {% endif %}
        </div>
      </div>
      {% endfor %}
    </div>
  </div>
</section>