<section id="gallery" class="py-24 bg-gray-50">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-16" data-aos="fade-up">
      <div class="w-12 h-px bg-primary mx-auto mb-6"></div>
      <h2 class="text-4xl font-light text-gray-900 mb-4">
        {{ sections.gallery.title }}
      </h2>
    </div>
    
    <div class="grid md:grid-cols-2 lg:grid-cols-3 gap-8">
      {% for item in sections.gallery.items %}
      <div class="group relative bg-white rounded-lg shadow-sm border border-gray-100 overflow-hidden hover:shadow-md transition-shadow duration-300" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <div class="aspect-[4/3] overflow-hidden">
          <img src="{{ item.src }}" 
               alt="{{ item.alt }}" 
               class="w-full h-full object-cover group-hover:scale-105 transition-transform duration-500">
        </div>
        
        {% if item.caption %}
        <div class="p-6">
          <h3 class="font-medium text-gray-900">{{ item.caption }}</h3>
        </div>
        {% endif %}
        
        {% if item.lightbox %}
        <div class="absolute top-4 right-4 w-10 h-10 bg-white/90 backdrop-blur-sm rounded-lg flex items-center justify-center opacity-0 group-hover:opacity-100 transition-opacity duration-300">
          <i class="ri-zoom-in-line text-gray-700"></i>
        </div>
        {% endif %}
      </div>
      {% endfor %}
    </div>
  </div>
</section>