<section id="challenges" class="py-24 bg-white">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-20" data-aos="fade-up">
      <span class="inline-block text-xs uppercase tracking-widest text-gray-500 mb-3">
        {{ sections.challenges.title }}
      </span>
      <h2 class="text-3xl sm:text-4xl font-light text-gray-900 mb-4">
        {{ sections.challenges.subtitle }}
      </h2>
      <div class="w-16 h-px bg-gray-300 mx-auto mb-6"></div>
    </div>
    
    <div class="grid grid-cols-2 md:grid-cols-4 gap-8">
      {% for item in sections.challenges.items %}
      <div class="text-center p-6 border border-gray-100 hover:shadow-sm transition-shadow duration-300" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <div class="text-3xl font-light text-gray-900 mb-3">{{ item.value }}</div>
        <div class="w-8 h-px bg-gray-300 mx-auto mb-3"></div>
        <div class="text-sm text-gray-600 font-light uppercase tracking-wide">{{ item.label }}</div>
        {% if item.description %}
        <p class="text-xs text-gray-500 mt-2 font-light">{{ item.description }}</p>
        {% endif %}
      </div>
      {% endfor %}
    </div>
  </div>
</section>